MethodChannelFcNativeVideoThumbnail class

An implementation of FcNativeVideoThumbnailPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveThumbnailToBytes({required String srcFile, required int width, required int height, String? format, bool? srcFileUri, FcVideoThumbnailTime? at, int? quality}) Future<Uint8List?>
override
saveThumbnailToFile({required String srcFile, required String destFile, required int width, required int height, String? format, bool? srcFileUri, FcVideoThumbnailTime? at, int? quality}) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited